@@ -8,10 +8,13 @@ import torch
 from . import Util
 from FModel.models import Clients
 BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
-save_dir=os.path.join(BASE_DIR, 'static', 'modelfile')
+import subprocess
+# save_dir=os.path.join(BASE_DIR, 'static', 'modelfile')
+save_dir=subprocess.getoutput("pwd")
 def index(request): 
     context= {}
     context['clients']=Util.getClients()
+    context['clients_count']=len(context['clients'])
     return render(request, 'index.html', context)
 @csrf_exempt
 def client_login(request):
@@ -32,6 +35,10 @@ def send_model(request):
         with  open(os.path.join(BASE_DIR, 'static', 'modelfile',key), 'wb') as f:
             for chunk in modelfile.chunks():
                 f.write(chunk)
+        ncl=Clients.objects.filter(Key=key).first()
+        if ncl:
+            ncl.Loss=test_loss
+            ncl.save()
         keys=[cl.Key for cl in Clients.objects.filter(Status=1)]
         result=Util.check_fed_model(save_dir,keys,test_acc,test_loss,10)
         context['result']=result
@@ -41,9 +48,10 @@ def get_status(request):
     context= {}
     if request.method == 'POST':
         key=request.POST.get('key')
-        save_dir=os.path.join(BASE_DIR, 'static', 'modelfile')
         keys=[cl.Key for cl in Clients.objects.filter(Status=1)]
         context['modelurl']=''
+        context['result']=Util.check_client_all(save_dir,keys)
+        context['clientstatus']=Util.check_client(save_dir,key)
         # if int(context['result'])==3:
         if os.path.exists(os.path.join(save_dir,'%s_model'%(key))):
             os.rename(os.path.join(save_dir,'%s_model'%(key)),os.path.join(save_dir,'%s_modelb'%(key)))
@@ -60,4 +68,16 @@ def changeStatus(request):
         key=request.GET.get('key')
         status=request.GET.get('status')
         context['result']=Util.setClientStatus(key,status)
+    return HttpResponse(json.dumps(context),content_type="application/json") 
+
+
+@csrf_exempt
+def deleteclient(request):
+    context= {}
+    if request.method == 'GET':
+        key=request.GET.get('key')
+        cl=Clients.objects.filter(Key=key).first()
+        if cl:
+            cl.delete()
+            context['result']=1
     return HttpResponse(json.dumps(context),content_type="application/json") 
\ No newline at end of file
